@@ -26,17 +26,18 @@
 /* #undef PAPILO_HAVE_FLOAT128 */
 #define PAPILO_HAVE_GMP
 #define PAPILO_COMMAND_LINE_AVAILABLE
+#define PAPILO_SERIALIZATION_AVAILABLE
 /* #undef PAPILO_HAVE_LUSOL */
 #define PAPILO_USE_STANDARD_HASHMAP
 #define PAPILO_USE_BOOST_IOSTREAMS_WITH_ZLIB
 #define PAPILO_USE_BOOST_IOSTREAMS_WITH_BZIP2
-/* #undef PAPILO_GITHASH_AVAILABLE */
+#define PAPILO_GITHASH_AVAILABLE
 #define BOOST_FOUND
 #define PAPILO_TBB
 
 #define PAPILO_VERSION_MAJOR 2
 #define PAPILO_VERSION_MINOR 2
-#define PAPILO_VERSION_PATCH 0
+#define PAPILO_VERSION_PATCH 1
 #define PAPILO_VERSION_TWEAK 0
 
 #ifdef PAPILO_HAVE_GMP
@@ -44,7 +45,7 @@
 #endif
 
 #ifdef PAPILO_GITHASH_AVAILABLE
-   #define PAPILO_GITHASH ""
+   #define PAPILO_GITHASH "3f1f0d53"
 #endif
 
 #endif
