@@ -44,6 +44,7 @@
 
 #include <fstream>
 
+#ifdef PAPILO_SERIALIZATION_AVAILABLE
 #include <boost/archive/text_iarchive.hpp>
 #include <boost/archive/text_oarchive.hpp>
 #include <boost/archive/tmpdir.hpp>
@@ -51,6 +52,7 @@
 #include <boost/serialization/list.hpp>
 #include <boost/serialization/utility.hpp>
 #include <boost/serialization/vector.hpp>
+#endif
 
 namespace papilo
 {
@@ -567,6 +569,10 @@ Postsolve<REAL>::apply_fix_infinity_variable_in_original_solution(
    bool isNegativeInfinity = values[first] < 0;
    int* row_indices = new int[number_rows];
    REAL* col_coefficents = new REAL[number_rows];
+
+   if( number_rows == 0 && bound == std::numeric_limits<int64_t>::max() )
+      solution = 0;
+
    if( isNegativeInfinity )
    {
       while( row_counter < number_rows )
@@ -656,16 +662,20 @@ Postsolve<REAL>::apply_fix_infinity_variable_in_original_solution(
          sum.add( -col_coefficents[k] * originalSolution.dual[row_indices[k]] );
       originalSolution.reducedCosts[col] = sum.get();
 
+      bool is_bound_infinity = bound == std::numeric_limits<int64_t>::max();
+
       // store the bounds of the variable
       if( isNegativeInfinity )
-         stored_bounds.set_bounds_of_variable( col, true, false, 0, bound );
+         stored_bounds.set_bounds_of_variable( col, true, is_bound_infinity, 0, bound );
       else
-         stored_bounds.set_bounds_of_variable( col, false, true, bound, 0 );
+         stored_bounds.set_bounds_of_variable( col, is_bound_infinity, true, bound, 0 );
 
       // set the basis depending on the status
       if( originalSolution.basisAvailabe )
       {
-         if( num.isEq( solution, bound ) )
+         if( number_rows == 0 && bound == std::numeric_limits<int64_t>::max() )
+            originalSolution.varBasisStatus[col] = VarBasisStatus::ZERO;
+         else if( num.isEq( solution, bound ) )
             if( isNegativeInfinity )
                originalSolution.varBasisStatus[col] = VarBasisStatus::ON_UPPER;
             else
@@ -862,7 +872,7 @@ Postsolve<REAL>::apply_row_bound_change_to_original_solution(
          {
             if( isLhs )
             {
-               if( num.isLT( factor, 0 ) )
+               if( factor < 0 )
                   originalSolution.rowBasisStatus[deleted_row] =
                       VarBasisStatus::ON_UPPER;
                else
@@ -872,7 +882,7 @@ Postsolve<REAL>::apply_row_bound_change_to_original_solution(
             }
             else
             {
-               if( num.isLT( factor, 0 ) )
+               if( factor < 0 )
                   originalSolution.rowBasisStatus[deleted_row] =
                       VarBasisStatus::ON_LOWER;
                else
@@ -895,8 +905,18 @@ Postsolve<REAL>::apply_row_bound_change_to_original_solution(
             }
             else
             {
-               originalSolution.rowBasisStatus[deleted_row] =
-                   originalSolution.rowBasisStatus[row];
+               if( factor > 0)
+               {
+                  originalSolution.rowBasisStatus[ deleted_row ] =
+                        originalSolution.rowBasisStatus[ row ];
+               }
+               else
+               {
+                  if( originalSolution.rowBasisStatus[ row ] == VarBasisStatus::ON_LOWER )
+                     originalSolution.rowBasisStatus[ deleted_row ] = VarBasisStatus::ON_UPPER;
+                  else if( originalSolution.rowBasisStatus[ row ] == VarBasisStatus::ON_UPPER )
+                     originalSolution.rowBasisStatus[ deleted_row ] = VarBasisStatus::ON_LOWER;
+               }
                originalSolution.rowBasisStatus[row] = VarBasisStatus::BASIC;
             }
          }
@@ -948,9 +968,9 @@ Postsolve<REAL>::apply_var_bound_change_forced_by_column_in_original_solution(
 
    const REAL reduced_costs = originalSolution.reducedCosts[col];
    bool changes_neg_reduced_costs =
-       ! isLowerBound && num.isLT( reduced_costs, 0 );
+       ! isLowerBound && num.isFeasLT( reduced_costs, 0 );
    bool changes_pos_reduced_costs =
-       isLowerBound && num.isGT( reduced_costs, 0 );
+       isLowerBound && num.isFeasGT( reduced_costs, 0 );
 
    int variables_removed_from_basis = 0;
 
@@ -958,7 +978,7 @@ Postsolve<REAL>::apply_var_bound_change_forced_by_column_in_original_solution(
    if( num.isFeasEq( new_value, originalSolution.primal[col] ) &&
        ( changes_neg_reduced_costs || changes_pos_reduced_costs ) )
    {
-      assert( ! num.isZero( reduced_costs ) );
+      assert( ! num.isFeasZero( reduced_costs ) );
       SavedRow<REAL> saved_row{
           num, i, types, start, indices, values, originalSolution.primal };
       int row = saved_row.getRow();
